@@ -1,5 +1,5 @@
 package Dist::Build;
-$Dist::Build::VERSION = '0.022';
+$Dist::Build::VERSION = '0.023';
 use strict;
 use warnings;
 
@@ -72,34 +72,13 @@ sub Build_PL {
 	$planner->create_phony('pure_all', 'code', 'manify', 'dynamic');
 	$planner->create_phony('build', 'pure_all');
 
+	$planner->load_extension('ExtUtils::Builder::CPAN::Tool');
 	$planner->add_delegate('meta', sub { $meta });
-	$planner->add_delegate('distribution', sub { $meta->name });
-	$planner->add_delegate('version', sub { version->new($meta->version) });
-	(my $main_module = $meta->name) =~ s/-/::/g;
-	$planner->add_delegate('main_module', sub { $main_module });
-	$planner->add_delegate('release_status', sub { $meta->release_status });
-	$planner->add_delegate('perl_path', sub { get_perl(config => $options{config}, %options) });
 
 	for my $variable (qw/config install_paths verbose uninst jobs pureperl_only/) {
 		$planner->add_delegate($variable, sub { $options{$variable} });
 	}
 
-	$planner->add_delegate('is_os', sub {
-			my ($self, @wanted) = @_;
-			return not not grep { $_ eq $^O } @wanted
-	});
-	$planner->add_delegate('is_os_type', sub {
-			my ($self, $wanted) = @_;
-			require Perl::OSType;
-			return Perl::OSType::is_os_type($wanted);
-	});
-
-	$planner->add_delegate('new_planner', sub {
-		my $inner = ExtUtils::Builder::Planner->new;
-		$inner->add_delegate('config', sub { $options{config} });
-		return $inner;
-	});
-
 	my @meta_fragments;
 	$planner->add_delegate('add_meta', sub {
 		my (undef, @fragments) = @_;
@@ -130,14 +109,15 @@ sub Build_PL {
 	save_json(catfile(qw/_build graph/), $serializer->serialize_plan($plan));
 	save_json(catfile(qw/_build params/), [ $args, \@env ]);
 
+	my $metahash = $meta->as_struct;
 	if (@meta_fragments) {
 		require CPAN::Meta::Merge;
 		my $merger = CPAN::Meta::Merge->new(default_version => '2');
-		my $metahash = $merger->merge($meta, @meta_fragments);
-		$metahash->{dynamic_config} = 0;
-		$meta = CPAN::Meta->create($metahash, { lazy_validation => 0 });
+		$metahash = $merger->merge($metahash, @meta_fragments);
 	}
-	$meta->save('MYMETA.json');
+	$metahash->{dynamic_config} = 0;
+	my $mymeta = CPAN::Meta->create($metahash, { lazy_validation => 0 });
+	$mymeta->save('MYMETA.json');
 
 	printf "Creating new 'Build' script for '%s' version '%s'\n", $meta->name, $meta->version;
 	my $dir = $meta->name eq 'Dist-Build' ? 'lib' : 'inc';
@@ -178,7 +158,7 @@ Dist::Build - A modern module builder, author tools not included!
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 DESCRIPTION
 
@@ -246,7 +226,7 @@ This module contains all commands used for the base actions of the module.
 
 =head1 DELEGATES
 
-By default, the following delegates are defined on your L<planner|ExtUtils::Builder::Planner>:
+All the usual delegates of the L<ExtUtils::Builder::CPAN::Tool> are defined on your L<planner|ExtUtils::Builder::Planner>, and additionally C<install_paths>.
 
 =over 4
 
